@@ -1,7 +1,7 @@
 # #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 # <HTTPretty - HTTP client mock for Python>
-# Copyright (C) <2011>  Gabriel Falcão <gabriel@nacaolivre.org>
+# Copyright (C) <2011-2012>  Gabriel Falcão <gabriel@nacaolivre.org>
 #
 # Permission is hereby granted, free of charge, to any person
 # obtaining a copy of this software and associated documentation
@@ -23,7 +23,7 @@
 # WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 # FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 # OTHER DEALINGS IN THE SOFTWARE.
-version = '0.5.1'
+version = '0.5.2'
 
 import re
 import socket
@@ -184,7 +184,7 @@ class fakesock(object):
                 self.truesock.close()
             self._closed = True
 
-        def makefile(self, mode, bufsize):
+        def makefile(self, mode='r', bufsize=-1):
             self._mode = mode
             self._bufsize = bufsize
 
@@ -231,12 +231,16 @@ class fakesock(object):
                         return self._true_sendall(data, *args, **kw)
 
             method, path, version = re.split('\s+', verb.strip(), 3)
+            # path might come with
+            s = urlsplit(path)
 
             headers, body = map(utf8, data.split('\r\n\r\n'))
 
             request = HTTPretty.historify_request(headers, body)
 
-            info = URIInfo(hostname=self._host, port=self._port, path=path,
+            info = URIInfo(hostname=self._host, port=self._port,
+                           path=s.path,
+                           query=s.query,
                            last_request=request)
 
             entries = []
@@ -356,7 +360,7 @@ class Entry(object):
         self.validate()
 
     def validate(self):
-        content_length_keys = 'Content-Length', 'content-cength'
+        content_length_keys = 'Content-Length', 'content-length'
         for key in content_length_keys:
             got = self.adding_headers.get(
                 key, self.forcing_headers.get(key, None))
@@ -377,8 +381,7 @@ class Entry(object):
                     'HTTPretty got inconsistent parameters. The header ' \
                     'Content-Length you registered expects size "%d" but ' \
                     'the body you registered for that has actually length ' \
-                    '"%d".\nFix that, or if you really want that, call ' \
-                    'register_uri with "fill_with" callback.' % (
+                    '"%d".' % (
                         igot, self.body_length,
                     )
                 )
@@ -497,8 +500,6 @@ class URIInfo(object):
             'hostname',
             'port',
             'path',
-            'query',
-            'fragment',
         )
         fmt = ", ".join(['%s="%s"' % (k, getattr(self, k, '')) for k in attrs])
         return ur'<httpretty.URIInfo(%s)>' % fmt
